.. zCluster documentation master file, created by
   sphinx-quickstart on Tue Sep 22 12:15:22 2020.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

zCluster - a tool for measuring photometric redshifts for galaxy clusters
=========================================================================

.. include:: ../README.rst

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   install
   usage
   commands
   reference

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
